@@ -29,5 +29,8 @@ class ImagePreviewWidget(Widget):
     	return template.render(Context({"name": name, "value": value, "width":width, "height": height}))
 
     def value_from_datadict(self, data, files, name):
-        return None if files[name] == "None" else files[name]
+        try:
+            return None if files[name] == "None" else files[name]
+        except:
+            return None
 
